@@ -7,7 +7,7 @@
 
 #include "identity.h"
 
-#include "kidentitymanagement_debug.h"
+#include "kidentitymanagementcore_debug.h"
 #include <KConfigGroup>
 #include <KEmailAddress>
 
@@ -15,25 +15,22 @@
 #include <QHostInfo>
 #include <QMimeData>
 
-using namespace KIdentityManagement;
+using namespace KIdentityManagementCore;
 
 static Identity *identityNull = nullptr;
 
-Q_DECLARE_METATYPE(KIdentityManagement::Signature)
+Q_DECLARE_METATYPE(KIdentityManagementCore::Signature)
 
 Identity::Identity(const QString &id, const QString &fullName, const QString &emailAddr, const QString &organization, const QString &replyToAddr)
 {
     qRegisterMetaType<Signature>();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    qRegisterMetaTypeStreamOperators<Signature>();
-#endif
     setProperty(QLatin1String(s_uoid), 0);
     setProperty(QLatin1String(s_identity), id);
     setProperty(QLatin1String(s_name), fullName);
     setProperty(QLatin1String(s_primaryEmail), emailAddr);
     setProperty(QLatin1String(s_organization), organization);
     setProperty(QLatin1String(s_replyto), replyToAddr);
-    // FIXME KF5: Sonnet::defaultLanguageName is gone
+    // FIXME KF6: Sonnet::defaultLanguageName is gone
     // setDictionary( Sonnet::defaultLanguageName() );
     setProperty(QLatin1String(s_disabledFcc), false);
     setProperty(QLatin1String(s_defaultDomainName), QHostInfo::localHostName());
@@ -49,8 +46,8 @@ const Identity &Identity::null()
 
 bool Identity::isNull() const
 {
-    bool empty = true;
     QHash<QString, QVariant>::const_iterator i = mPropertiesMap.constBegin();
+
     while (i != mPropertiesMap.constEnd()) {
         const QString &key = i.key();
         // Take into account that the defaultDomainName for a null identity is not empty
@@ -70,20 +67,14 @@ bool Identity::isNull() const
         }
         // The uoid is 0 by default, so ignore this
         if (!(key == QLatin1String(s_uoid) && i.value().toUInt() == 0)) {
-            if (!i.value().isNull()
-                || (
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                    i.value().type() == QVariant::String
-#else
-                    i.value().metaType().id() == QMetaType::QString
-#endif
-                    && !i.value().toString().isEmpty())) {
-                empty = false;
+            if (!i.value().isNull() || (i.value().metaType().id() == QMetaType::QString && !i.value().toString().isEmpty())) {
+                return false;
             }
         }
         ++i;
     }
-    return empty;
+
+    return true;
 }
 
 void Identity::readConfig(const KConfigGroup &config)
@@ -170,7 +161,7 @@ Identity Identity::fromMimeData(const QMimeData *md)
 
 // ------------------ Operators --------------------------//
 
-QDataStream &KIdentityManagement::operator<<(QDataStream &stream, const KIdentityManagement::Identity &i)
+QDataStream &KIdentityManagementCore::operator<<(QDataStream &stream, const KIdentityManagementCore::Identity &i)
 {
     return stream << static_cast<quint32>(i.uoid()) << i.mPropertiesMap[QLatin1String(s_identity)] << i.mPropertiesMap[QLatin1String(s_name)]
                   << i.mPropertiesMap[QLatin1String(s_organization)] << i.mPropertiesMap[QLatin1String(s_pgps)] << i.mPropertiesMap[QLatin1String(s_pgpe)]
@@ -188,7 +179,7 @@ QDataStream &KIdentityManagement::operator<<(QDataStream &stream, const KIdentit
                   << i.mPropertiesMap[QLatin1String(s_warnnotencrypt)] << i.mPropertiesMap[QLatin1String(s_warnnotsign)];
 }
 
-QDataStream &KIdentityManagement::operator>>(QDataStream &stream, KIdentityManagement::Identity &i)
+QDataStream &KIdentityManagementCore::operator>>(QDataStream &stream, KIdentityManagementCore::Identity &i)
 {
     quint32 uoid;
     stream >> uoid >> i.mPropertiesMap[QLatin1String(s_identity)] >> i.mPropertiesMap[QLatin1String(s_name)] >> i.mPropertiesMap[QLatin1String(s_organization)]
@@ -512,13 +503,7 @@ void Identity::setProperty(const QString &key, const QVariant &value)
     if (key == QLatin1String(s_signature)) {
         mSignature = value.value<Signature>();
     } else {
-        if (value.isNull() ||
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            (value.type() == QVariant::String
-#else
-            (value.metaType().id() == QMetaType::QString
-#endif
-             && value.toString().isEmpty())) {
+        if (value.isNull() || (value.metaType().id() == QMetaType::QString && value.toString().isEmpty())) {
             mPropertiesMap.remove(key);
         } else {
             mPropertiesMap.insert(key, value);
@@ -746,7 +731,7 @@ void Identity::setPgpAutoEncrypt(bool autoEncrypt)
     setProperty(QLatin1String(s_pgpautoencrypt), autoEncrypt);
 }
 
-bool KIdentityManagement::Identity::autocryptEnabled() const
+bool KIdentityManagementCore::Identity::autocryptEnabled() const
 {
     const auto var = property(QLatin1String(s_autocryptEnabled));
     if (var.isNull()) {
@@ -761,7 +746,7 @@ void Identity::setAutocryptEnabled(const bool on)
     setProperty(QLatin1String(s_autocryptEnabled), on);
 }
 
-bool KIdentityManagement::Identity::autocryptPrefer() const
+bool KIdentityManagementCore::Identity::autocryptPrefer() const
 {
     const auto var = property(QLatin1String(s_autocryptPrefer));
     if (var.isNull()) {
@@ -776,7 +761,7 @@ void Identity::setAutocryptPrefer(const bool on)
     setProperty(QLatin1String(s_autocryptPrefer), on);
 }
 
-bool KIdentityManagement::Identity::encryptionOverride() const
+bool KIdentityManagementCore::Identity::encryptionOverride() const
 {
     const auto var = property(QLatin1String(s_encryptionOverride));
     if (var.isNull()) {
@@ -791,7 +776,7 @@ void Identity::setEncryptionOverride(const bool on)
     setProperty(QLatin1String(s_encryptionOverride), on);
 }
 
-bool KIdentityManagement::Identity::warnNotEncrypt() const
+bool KIdentityManagementCore::Identity::warnNotEncrypt() const
 {
     const auto var = property(QLatin1String(s_warnnotencrypt));
     if (var.isNull()) {
@@ -806,7 +791,7 @@ void Identity::setWarnNotEncrypt(const bool on)
     setProperty(QLatin1String(s_warnnotencrypt), on);
 }
 
-bool KIdentityManagement::Identity::warnNotSign() const
+bool KIdentityManagementCore::Identity::warnNotSign() const
 {
     const auto var = property(QLatin1String(s_warnnotsign));
     if (var.isNull()) {
