@@ -24,6 +24,7 @@
 #include <KPIMTextEdit/RichTextComposer>
 #include <KPIMTextEdit/RichTextComposerControler>
 #include <KPIMTextEdit/RichTextComposerImages>
+#include <TextCustomEditor/RichTextEditor>
 
 #include <QCheckBox>
 #include <QComboBox>
@@ -38,11 +39,11 @@
 #include <QStandardPaths>
 #include <cassert>
 
-#include <KPIMTextEdit/RichTextEditorWidget>
+#include <TextCustomEditor/RichTextEditorWidget>
 
-using namespace KIdentityManagement;
+using namespace KIdentityManagementWidgets;
 
-namespace KIdentityManagement
+namespace KIdentityManagementWidgets
 {
 /**
    Private class that helps to provide binary compatibility between releases.
@@ -56,10 +57,10 @@ public:
     void init();
     // Returns the current text of the textedit as HTML code, but strips
     // unnecessary tags Qt inserts
-    Q_REQUIRED_RESULT QString asCleanedHTML() const;
+    [[nodiscard]] QString asCleanedHTML() const;
 
     QString imageLocation;
-    SignatureConfigurator *q;
+    SignatureConfigurator *const q;
     QCheckBox *mEnableCheck = nullptr;
     QCheckBox *mHtmlCheck = nullptr;
     QComboBox *mSourceCombo = nullptr;
@@ -156,7 +157,7 @@ void SignatureConfiguratorPrivate::init()
 
     mTextEdit = new KPIMTextEdit::RichTextComposer(q);
 
-    auto richTextEditorwidget = new KPIMTextEdit::RichTextEditorWidget(mTextEdit, q);
+    auto richTextEditorwidget = new TextCustomEditor::RichTextEditorWidget(mTextEdit, q);
     page_vlay->addWidget(richTextEditorwidget, 2);
     mTextEdit->setWhatsThis(i18n("Use this field to enter an arbitrary static signature."));
 
@@ -215,7 +216,7 @@ void SignatureConfiguratorPrivate::init()
     hlay = new QHBoxLayout(); // inherits spacing
     page_vlay->addLayout(hlay);
     mFileRequester = new KUrlRequester(page);
-    mFileRequester->setFilter(QStringLiteral("*.txt"));
+    mFileRequester->setNameFilter(i18n("Text File (*.txt)"));
     mFileRequester->setWhatsThis(
         i18n("Use this requester to specify a text file that contains your "
              "signature. It will be read every time you create a new mail or "
@@ -414,7 +415,7 @@ void SignatureConfigurator::slotUrlChanged()
     const QString file = filePath();
     const QFileInfo infoFile(file);
     if (infoFile.isFile() && (infoFile.size() > 1000)) {
-        KMessageBox::information(this, i18n("This text file size exceeds 1kb."), i18n("Text File Size"));
+        KMessageBox::information(this, i18n("This text file size exceeds 1kb."), i18nc("@title:window", "Text File Size"));
     }
     d->mEditButton->setDisabled(file.isEmpty());
 }
@@ -461,7 +462,7 @@ void SignatureConfigurator::setImageLocation(const QString &path)
     d->imageLocation = path;
 }
 
-void SignatureConfigurator::setImageLocation(const Identity &identity)
+void SignatureConfigurator::setImageLocation(const KIdentityManagementCore::Identity &identity)
 {
     const QString dir =
         QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/emailidentities/%1/").arg(QString::number(identity.uoid()));
@@ -469,3 +470,5 @@ void SignatureConfigurator::setImageLocation(const Identity &identity)
     setImageLocation(dir);
 }
 }
+
+#include "moc_signatureconfigurator.cpp"
